# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name haddock

# needs hspec
%bcond_with tests

# no useful debuginfo for Haskell packages without C sources
%global debug_package %{nil}

Name:           %{pkg_name}
Version:        2.13.2
Release:        5%{?dist}
Summary:        A documentation-generation tool for Haskell libraries

License:        BSD
Url:            http://hackage.haskell.org/package/%{name}
Source0:        http://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  alex
BuildRequires:  chrpath
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-ghc-devel
BuildRequires:  ghc-ghc-paths-devel
BuildRequires:  ghc-xhtml-devel
BuildRequires:  happy
%if %{with tests}
BuildRequires:  ghc-process-devel
%endif
# End cabal-rpm deps
BuildRequires:  autoconf
BuildRequires:  docbook-style-xsl
BuildRequires:  libxslt

%description
Haddock is a documentation-generation tool for Haskell libraries.


%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.


%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Provides:       ghc-%{name}-static = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       ghc-%{name}%{?_isa} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.


%prep
%setup -q


%build
%ghc_lib_build
cd doc
autoreconf
./configure --prefix=%{_prefix} --libdir=%{_libdir}
make html
cd ..



%install
%ghc_lib_install

%ghc_fix_dynamic_rpath %{name}

# version the binary so not to conflict with ghc
mv %{buildroot}%{_bindir}/%{name}{,-%{version}}


%check
%if %{with tests}
%cabal test
%endif


%post -n ghc-%{name}-devel
%ghc_pkg_recache


%postun -n ghc-%{name}-devel
%ghc_pkg_recache


%files
%doc LICENSE
%doc README
%doc doc/haddock
%{_bindir}/%{name}-%{version}
%{_datadir}/%{name}-%{version}


%files -n ghc-%{name} -f ghc-%{name}.files
%doc LICENSE


%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGES


%changelog
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.13.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jun 16 2014 Jens Petersen <petersen@redhat.com> - 2.13.2-4
- update to cblrpm-0.8.11
- include documentation

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.13.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.13.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jun 10 2013 Jens Petersen <petersen@redhat.com> - 2.13.2-1
- update to 2.13.2

* Fri Jun 07 2013 Jens Petersen <petersen@redhat.com> - 2.10.0-9
- update to new simplified Haskell Packaging Guidelines

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.10.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Nov 17 2012 Jens Petersen <petersen@redhat.com> - 2.10.0-7
- update with cabal-rpm

* Mon Oct 01 2012 Lakshmi Narasimhan T V <lakshminaras2002@gmail.com> - 2.10.0-6
- Rebuild for ghc-7.4.1

* Sat Aug 11 2012 Lakshmi Narasimhan T V <lakshminaras2002@gmail.com> - 2.10.0-5
- Rebuild for libffi

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.10.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 16 2012 Jens Petersen <petersen@redhat.com> - 2.10.0-3
- change prof BRs to devel

* Fri Jun 15 2012 Jens Petersen <petersen@redhat.com> - 2.10.0-2
- rebuild

* Tue Mar 20 2012 Jens Petersen <petersen@redhat.com> - 2.10.0-1
- update to 2.10.0

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jan  5 2012 Jens Petersen <petersen@redhat.com> - 2.9.2-5
- update to cabal2spec-0.25.2

* Mon Jan 2 2012 Lakshmi Narasimhan T V <lakshminaras2002@gmail.com> - 2.9.2-4
- rebuild with new ghc-xhtml

* Fri Oct 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 2.9.2-3.2
- rebuild with new gmp without compat lib

* Tue Oct 11 2011 Peter Schiffer <pschiffe@redhat.com> - 2.9.2-3.1
- rebuild with new gmp

* Tue Jun 21 2011 Lakshmi Narasimhan T V <lakshminaras2002@gmail.com> - 2.9.2-3
- Update to  cabal2spec-0.23.2

* Fri Apr  1 2011 Jens Petersen <petersen@redhat.com> - 2.9.2-2
- minor changes to sync with cabal2spec-0.22.5

* Fri Mar 11 2011 Lakshmi Narasimhan T V <lakshminaras2002@gmail.com> - 2.9.2-1
- Upgrade to haddock-2.9.2

* Thu Mar 10 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.9.1-3
- Enable build on sparcv9

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Jan 25 2011 Lakshmi Narasimhan <lakshminaras2002@gmail.com> - 2.9.1-1
- update to 2.9.1

* Thu Jan  6 2011 Jens Petersen <petersen@redhat.com> - 2.7.2-3
- update to cabal2spec-0.22.4

* Wed Nov 10 2010 Lakshmi Narasimhan <lakshminaras2002@gmail.com> - 2.7.2-2
- Include LICENSE and README.

* Fri Nov 5 2010 Lakshmi Narasimhan <lakshminaras2002@gmail.com> - 2.7.2-1
- Modified dependencies. Added alex and happy.
- Changing binary executable name to haddock-version. ghc already ships with haddock binary.

* Fri Nov  5 2010 Fedora Haskell SIG <haskell-devel@lists.fedoraproject.org> - 2.7.2-0
- initial packaging for Fedora automatically generated by cabal2spec-0.22.2
